// DebugExpressionCallBack.h
// (c) 2003 exeal

#ifndef _DEBUG_EXPRESSION_CALL_BACK_H_
#define _DEBUG_EXPRESSION_CALL_BACK_H_

#include <activdbg.h>
#include "..\Armaiti\UnknownImpl.h"
using namespace Armaiti;


// CDebugExpressionCallBack class definition
/////////////////////////////////////////////////////////////////////////////

namespace Alpha {

///	IDebugExpressionCallBack ̕WIȎ
class CDebugExpressionCallBack :
		public IUnknownImpl<MultiThreadedRefCount>,
		public IDebugExpressionCallBack {
	// RXgN^
public:
	CDebugExpressionCallBack();
	~CDebugExpressionCallBack();

	// \bh
public:
	// IUnknown C^[tFCX
	IMPLEMENT_UNKNOWN()
	BEGIN_INTERFACE_TABLE()
		IMPLEMENTS_LEFTMOST_INTERFACE(IDebugExpressionCallBack)
	END_INTERFACE_TABLE()

	// IDebugExpressionCallBack C^[tFCX
	STDMETHODIMP	onComplete();

	bool	WaitForCompletion(unsigned long nMilliseconds = INFINITE);

	// f[^o
private:
	HANDLE	m_hCompletionEvent;
};

} /* namespace Alpha */

#endif /* _DEBUG_EXPRESSION_CALL_BACK_H_ */

/* [EOF] */